from setuptools import setup

setup(name='vin_distributions',
      version='0.1',
      description='Gaussian distributions',
      packages=['vin_distributions'],
      author = 'Vinit Kanse',
      author_email = 'randomwave45@gmail.com',
      zip_safe=False)
